# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from src.client.generated.models.test_case_bulk_cf_move_strategy import TestCaseBulkCfMoveStrategy
from src.client.generated.models.test_case_selection_dto_v2 import TestCaseSelectionDtoV2
from typing import Optional, Set
from typing_extensions import Self

class TestCaseBulkCloneDtoV2(BaseModel):
    """
    TestCaseBulkCloneDtoV2
    """ # noqa: E501
    cf_mapping: Optional[Dict[str, StrictInt]] = Field(default=None, alias="cfMapping")
    ignore_attachments: Optional[StrictBool] = Field(default=None, alias="ignoreAttachments")
    ignore_cfv: Optional[StrictBool] = Field(default=None, alias="ignoreCfv")
    ignore_issue_links: Optional[StrictBool] = Field(default=None, alias="ignoreIssueLinks")
    ignore_links: Optional[StrictBool] = Field(default=None, alias="ignoreLinks")
    ignore_members: Optional[StrictBool] = Field(default=None, alias="ignoreMembers")
    ignore_parameters: Optional[StrictBool] = Field(default=None, alias="ignoreParameters")
    ignore_relations: Optional[StrictBool] = Field(default=None, alias="ignoreRelations")
    ignore_scenario: Optional[StrictBool] = Field(default=None, alias="ignoreScenario")
    ignore_tags: Optional[StrictBool] = Field(default=None, alias="ignoreTags")
    ignore_test_keys: Optional[StrictBool] = Field(default=None, alias="ignoreTestKeys")
    name_suffix: Optional[StrictStr] = Field(default=None, alias="nameSuffix")
    selection: TestCaseSelectionDtoV2
    status_id: Optional[StrictInt] = Field(default=None, alias="statusId")
    strategy: Optional[TestCaseBulkCfMoveStrategy] = None
    to_project_id: Optional[StrictInt] = Field(default=None, alias="toProjectId")
    workflow_id: Optional[StrictInt] = Field(default=None, alias="workflowId")
    __properties: ClassVar[List[str]] = ["cfMapping", "ignoreAttachments", "ignoreCfv", "ignoreIssueLinks", "ignoreLinks", "ignoreMembers", "ignoreParameters", "ignoreRelations", "ignoreScenario", "ignoreTags", "ignoreTestKeys", "nameSuffix", "selection", "statusId", "strategy", "toProjectId", "workflowId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TestCaseBulkCloneDtoV2 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of selection
        if self.selection:
            _dict['selection'] = self.selection.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TestCaseBulkCloneDtoV2 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cfMapping": obj.get("cfMapping"),
            "ignoreAttachments": obj.get("ignoreAttachments"),
            "ignoreCfv": obj.get("ignoreCfv"),
            "ignoreIssueLinks": obj.get("ignoreIssueLinks"),
            "ignoreLinks": obj.get("ignoreLinks"),
            "ignoreMembers": obj.get("ignoreMembers"),
            "ignoreParameters": obj.get("ignoreParameters"),
            "ignoreRelations": obj.get("ignoreRelations"),
            "ignoreScenario": obj.get("ignoreScenario"),
            "ignoreTags": obj.get("ignoreTags"),
            "ignoreTestKeys": obj.get("ignoreTestKeys"),
            "nameSuffix": obj.get("nameSuffix"),
            "selection": TestCaseSelectionDtoV2.from_dict(obj["selection"]) if obj.get("selection") is not None else None,
            "statusId": obj.get("statusId"),
            "strategy": obj.get("strategy"),
            "toProjectId": obj.get("toProjectId"),
            "workflowId": obj.get("workflowId")
        })
        return _obj


