# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from src.client.generated.models.id_and_name_only_dto import IdAndNameOnlyDto
from src.client.generated.models.tree_selection_dto import TreeSelectionDto
from typing import Optional, Set
from typing_extensions import Self

class TestPlanDto(BaseModel):
    """
    TestPlanDto
    """ # noqa: E501
    base_rql: Optional[StrictStr] = Field(default=None, alias="baseRql")
    created_by: Optional[StrictStr] = Field(default=None, alias="createdBy")
    created_date: Optional[StrictInt] = Field(default=None, alias="createdDate")
    id: Optional[StrictInt] = None
    last_modified_by: Optional[StrictStr] = Field(default=None, alias="lastModifiedBy")
    last_modified_date: Optional[StrictInt] = Field(default=None, alias="lastModifiedDate")
    name: Optional[StrictStr] = None
    project_id: Optional[StrictInt] = Field(default=None, alias="projectId")
    test_cases_count: Optional[StrictInt] = Field(default=None, alias="testCasesCount")
    tree: Optional[IdAndNameOnlyDto] = None
    tree_selection: Optional[TreeSelectionDto] = Field(default=None, alias="treeSelection")
    __properties: ClassVar[List[str]] = ["baseRql", "createdBy", "createdDate", "id", "lastModifiedBy", "lastModifiedDate", "name", "projectId", "testCasesCount", "tree", "treeSelection"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TestPlanDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of tree
        if self.tree:
            _dict['tree'] = self.tree.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tree_selection
        if self.tree_selection:
            _dict['treeSelection'] = self.tree_selection.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TestPlanDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "baseRql": obj.get("baseRql"),
            "createdBy": obj.get("createdBy"),
            "createdDate": obj.get("createdDate"),
            "id": obj.get("id"),
            "lastModifiedBy": obj.get("lastModifiedBy"),
            "lastModifiedDate": obj.get("lastModifiedDate"),
            "name": obj.get("name"),
            "projectId": obj.get("projectId"),
            "testCasesCount": obj.get("testCasesCount"),
            "tree": IdAndNameOnlyDto.from_dict(obj["tree"]) if obj.get("tree") is not None else None,
            "treeSelection": TreeSelectionDto.from_dict(obj["treeSelection"]) if obj.get("treeSelection") is not None else None
        })
        return _obj


