# coding: utf-8

"""
    allure-testops-service

    Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

    The version of the OpenAPI document: 25.4.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from src.client.generated.models.integration_fields_form_dto_default_project_fields_inner import IntegrationFieldsFormDtoDefaultProjectFieldsInner
from typing import Optional, Set
from typing_extensions import Self

class IntegrationFieldsFormDto(BaseModel):
    """
    IntegrationFieldsFormDto
    """ # noqa: E501
    default_project_fields: Optional[List[IntegrationFieldsFormDtoDefaultProjectFieldsInner]] = Field(default=None, alias="defaultProjectFields")
    default_project_fields_values: Optional[Dict[str, Any]] = Field(default=None, alias="defaultProjectFieldsValues")
    default_secret_fields: Optional[List[IntegrationFieldsFormDtoDefaultProjectFieldsInner]] = Field(default=None, alias="defaultSecretFields")
    default_secret_specified: Optional[StrictBool] = Field(default=None, alias="defaultSecretSpecified")
    global_fields: Optional[List[IntegrationFieldsFormDtoDefaultProjectFieldsInner]] = Field(default=None, alias="globalFields")
    global_fields_values: Optional[Dict[str, Any]] = Field(default=None, alias="globalFieldsValues")
    __properties: ClassVar[List[str]] = ["defaultProjectFields", "defaultProjectFieldsValues", "defaultSecretFields", "defaultSecretSpecified", "globalFields", "globalFieldsValues"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IntegrationFieldsFormDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in default_project_fields (list)
        _items = []
        if self.default_project_fields:
            for _item_default_project_fields in self.default_project_fields:
                if _item_default_project_fields:
                    _items.append(_item_default_project_fields.to_dict())
            _dict['defaultProjectFields'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in default_secret_fields (list)
        _items = []
        if self.default_secret_fields:
            for _item_default_secret_fields in self.default_secret_fields:
                if _item_default_secret_fields:
                    _items.append(_item_default_secret_fields.to_dict())
            _dict['defaultSecretFields'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in global_fields (list)
        _items = []
        if self.global_fields:
            for _item_global_fields in self.global_fields:
                if _item_global_fields:
                    _items.append(_item_global_fields.to_dict())
            _dict['globalFields'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IntegrationFieldsFormDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "defaultProjectFields": [IntegrationFieldsFormDtoDefaultProjectFieldsInner.from_dict(_item) for _item in obj["defaultProjectFields"]] if obj.get("defaultProjectFields") is not None else None,
            "defaultProjectFieldsValues": obj.get("defaultProjectFieldsValues"),
            "defaultSecretFields": [IntegrationFieldsFormDtoDefaultProjectFieldsInner.from_dict(_item) for _item in obj["defaultSecretFields"]] if obj.get("defaultSecretFields") is not None else None,
            "defaultSecretSpecified": obj.get("defaultSecretSpecified"),
            "globalFields": [IntegrationFieldsFormDtoDefaultProjectFieldsInner.from_dict(_item) for _item in obj["globalFields"]] if obj.get("globalFields") is not None else None,
            "globalFieldsValues": obj.get("globalFieldsValues")
        })
        return _obj


